@@ -1,11 +1,11 @@
 /*
-   rc-logger.c
-   Spawns a logging daemon to capture stdout and stderr so we can log
-   them to a buffer and/or files.
-   */
+  rc-logger.c
+  Spawns a logging daemon to capture stdout and stderr so we can log
+  them to a buffer and/or files.
+*/
 
 /*
- * Copyright 2007-2008 Roy Marples <roy@marples.name>
+ * Copyright (c) 2007-2008 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -46,11 +46,11 @@
 #include <unistd.h>
 
 #ifdef __linux__
-# include <pty.h>
+#  include <pty.h>
 #elif defined(__NetBSD__) || defined(__OpenBSD__)
-# include <util.h>
+#  include <util.h>
 #else
-# include <libutil.h>
+#  include <libutil.h>
 #endif
 
 #include "einfo.h"
@@ -60,7 +60,7 @@
 
 #define LOGFILE RC_SVCDIR "/rc.log"
 #define PERMLOG "/var/log/rc.log"
-#define MOVELOG	"cat " LOGFILE " 2>/dev/null >>" PERMLOG " && " \
+#define MOVELOG	"cat " LOGFILE " 2>/dev/null >>" PERMLOG " && "		      \
 	"rm -f " LOGFILE
 
 static int signal_pipe[2] = { -1, -1 };
@@ -78,11 +78,12 @@ pid_t rc_logger_pid = -1;
 int rc_logger_tty = -1;
 bool rc_in_logger = false;
 
-static void write_log(int logfd, const char *buffer, size_t bytes)
+static void
+write_log(int logfd, const char *buffer, size_t bytes)
 {
 	const char *p = buffer;
 
-	while ((size_t) (p - buffer) < bytes) {
+	while ((size_t)(p - buffer) < bytes) {
 		switch (*p) {
 		case '\r':
 			goto cont;
@@ -99,8 +100,9 @@ static void write_log(int logfd, const char *buffer, size_t bytes)
 			break;
 		}
 
-		if (! in_escape) {
-			write(logfd, p++, 1);
+		if (!in_escape) {
+			if (write(logfd, p++, 1) == -1)
+				eerror("write: %s", strerror(errno));
 			continue;
 		}
 
@@ -110,7 +112,9 @@ cont:
 		p++;
 	}
 }
-static void write_time(FILE *f, const char *s)
+
+static void
+write_time(FILE *f, const char *s)
 {
 	time_t now = time(NULL);
 	struct tm *tm = localtime(&now);
@@ -119,12 +123,14 @@ static void write_time(FILE *f, const char *s)
 	fflush(f);
 }
 
-void rc_logger_close(void)
+void
+rc_logger_close(void)
 {
 	int sig = SIGTERM;
 
 	if (signal_pipe[1] > -1) {
-		write(signal_pipe[1], &sig, sizeof(sig));
+		if (write(signal_pipe[1], &sig, sizeof(sig)) == -1)
+			eerror("write: %s", strerror(errno));
 		close(signal_pipe[1]);
 		signal_pipe[1] = -1;
 	}
@@ -138,7 +144,8 @@ void rc_logger_close(void)
 		dup2(fd_stderr, STDERR_FILENO);
 }
 
-void rc_logger_open(const char *level)
+void
+rc_logger_open(const char *level)
 {
 	int slave_tty;
 	struct termios tt;
@@ -150,9 +157,6 @@ void rc_logger_open(const char *level)
 	int i;
 	FILE *log = NULL;
 
-	if (!isatty(STDOUT_FILENO))
-		return;
-
 	if (!rc_conf_yesno("rc_logger"))
 		return;
 
@@ -160,15 +164,17 @@ void rc_logger_open(const char *level)
 		eerrorx("pipe: %s", strerror(errno));
 	for (i = 0; i < 2; i++)
 		if ((s = fcntl (signal_pipe[i], F_GETFD, 0) == -1 ||
-		     fcntl (signal_pipe[i], F_SETFD, s | FD_CLOEXEC) == -1))
+			fcntl (signal_pipe[i], F_SETFD, s | FD_CLOEXEC) == -1))
 			eerrorx("fcntl: %s", strerror (errno));
 
-	tcgetattr(STDOUT_FILENO, &tt);
-	ioctl(STDOUT_FILENO, TIOCGWINSZ, &ws);
-
-	/* /dev/pts may not be available yet */
-	if (openpty(&rc_logger_tty, &slave_tty, NULL, &tt, &ws))
-		return;
+	if (isatty(STDOUT_FILENO)) {
+		tcgetattr(STDOUT_FILENO, &tt);
+		ioctl(STDOUT_FILENO, TIOCGWINSZ, &ws);
+		if (openpty(&rc_logger_tty, &slave_tty, NULL, &tt, &ws))
+			return;
+	} else 
+		if (openpty(&rc_logger_tty, &slave_tty, NULL, NULL, NULL))
+			return;
 
 	if ((s = fcntl(rc_logger_tty, F_GETFD, 0)) == 0)
 		fcntl(rc_logger_tty, F_SETFD, s | FD_CLOEXEC);
@@ -203,36 +209,39 @@ void rc_logger_open(const char *level)
 		if (rc_logger_tty >= 0)
 			fd[1].fd = rc_logger_tty;
 		for (;;) {
-			if ((s = poll(fd, rc_logger_tty >= 0 ? 2 : 1, -1)) == -1) {
+			if ((s = poll(fd,
+				    rc_logger_tty >= 0 ? 2 : 1, -1)) == -1)
+			{
 				eerror("poll: %s", strerror(errno));
 				break;
-			}
+			} else if (s == 0)
+				continue;
 
-			if (s > 0) {
-				if (fd[1].revents & (POLLIN | POLLHUP)) {
-					memset(buffer, 0, BUFSIZ);
-					bytes = read(rc_logger_tty, buffer, BUFSIZ);
-					write(STDOUT_FILENO, buffer, bytes);
+			if (fd[1].revents & (POLLIN | POLLHUP)) {
+				memset(buffer, 0, BUFSIZ);
+				bytes = read(rc_logger_tty, buffer, BUFSIZ);
+				if (write(STDOUT_FILENO, buffer, bytes) == -1)
+					eerror("write: %s", strerror(errno));
 
-					if (log)
-						write_log(fileno (log), buffer, bytes);
-					else {
-						if (logbuf_size - logbuf_len < bytes) {
-							logbuf_size += BUFSIZ * 10;
-							logbuf = xrealloc(logbuf,
-									  sizeof(char ) *
-									  logbuf_size);
-						}
-
-						memcpy(logbuf + logbuf_len, buffer, bytes);
-						logbuf_len += bytes;
+				if (log)
+					write_log(fileno (log), buffer, bytes);
+				else {
+					if (logbuf_size - logbuf_len < bytes) {
+						logbuf_size += BUFSIZ * 10;
+						logbuf = xrealloc(logbuf,
+						    sizeof(char ) *
+						    logbuf_size);
 					}
-				}
 
-				/* Only SIGTERMS signals come down this pipe */
-				if (fd[0].revents & (POLLIN | POLLHUP))
-					break;
+					memcpy(logbuf + logbuf_len,
+					    buffer, bytes);
+					logbuf_len += bytes;
+				}
 			}
+
+			/* Only SIGTERMS signals come down this pipe */
+			if (fd[0].revents & (POLLIN | POLLHUP))
+				break;
 		}
 		free(buffer);
 		if (logbuf) {
@@ -247,10 +256,10 @@ void rc_logger_open(const char *level)
 			fclose(log);
 		}
 
-		/* Try and cat our new logfile to a more permament location and then
-		 * punt it */
-		system(MOVELOG);
-
+		/* Try and cat our new logfile to a more permament location
+		   and then punt it */
+		if (system(MOVELOG) == -1)
+			eerror("system: %s: %s", MOVELOG, strerror(errno));
 		exit(0);
 		/* NOTREACHED */
 
