@@ -1,10 +1,10 @@
 /*
-   rc-service.c
-   Finds all OpenRC services
-   */
+  rc-service.c
+  Finds all OpenRC services
+*/
 
 /*
- * Copyright 2008 Roy Marples <roy@marples.name>
+ * Copyright (c) 2008 Roy Marples <roy@marples.name>
  * All rights reserved
 
  * Redistribution and use in source and binary forms, with or without
@@ -43,15 +43,17 @@
 extern char *applet;
 
 #include "_usage.h"
-#define getoptstring "e:lr:" getoptstring_COMMON
+#define getoptstring "e:ilr:" getoptstring_COMMON
 static const struct option longopts[] = {
-	{ "exists",  1, NULL, 'e' },
-	{ "list",    0, NULL, 'l' },
-	{ "resolve", 1, NULL, 'r' },
+	{ "exists",   1, NULL, 'e' },
+	{ "ifexists", 0, NULL, 'i' },
+	{ "list",     0, NULL, 'l' },
+	{ "resolve",  1, NULL, 'r' },
 	longopts_COMMON
 };
 static const char * const longopts_help[] = {
 	"tests if the service exists or not",
+	"if the service exsits then run the command",
 	"list all available services",
 	"resolve the service name to an init script",
 	longopts_help_COMMON
@@ -65,12 +67,13 @@ rc_service(int argc, char **argv)
 	char *service;
 	RC_STRINGLIST *list;
 	RC_STRING *s;
+	bool if_exists = false;
 
 	/* Ensure that we are only quiet when explicitly told to be */
 	unsetenv("EINFO_QUIET");
 
 	while ((opt = getopt_long(argc, argv, getoptstring,
-				  longopts, (int *) 0)) != -1)
+		    longopts, (int *) 0)) != -1)
 	{
 		switch (opt) {
 		case 'e':
@@ -81,13 +84,16 @@ rc_service(int argc, char **argv)
 #endif
 			return opt;
 			/* NOTREACHED */
+		case 'i':
+			if_exists = true;
+			break;
 		case 'l':
 			list = rc_services_in_runlevel(NULL);
-			if (!TAILQ_FIRST(list))
+			if (TAILQ_FIRST(list) == NULL)
 				return EXIT_FAILURE;
 			rc_stringlist_sort(&list);
 			TAILQ_FOREACH(s, list, entries)
-				printf("%s\n", s->value);
+			    printf("%s\n", s->value);
 #ifdef DEBUG_MEMORY
 			rc_stringlist_free(list);
 #endif
@@ -95,7 +101,7 @@ rc_service(int argc, char **argv)
 			/* NOTREACHED */
 		case 'r':
 			service = rc_service_resolve(optarg);
-			if (!service)
+			if (service == NULL)
 				return EXIT_FAILURE;
 			printf("%s\n", service);
 #ifdef DEBUG_MEMORY
@@ -104,16 +110,19 @@ rc_service(int argc, char **argv)
 			return EXIT_SUCCESS;
 			/* NOTREACHED */
 
-		case_RC_COMMON_GETOPT
-		}
+			case_RC_COMMON_GETOPT
+			    }
 	}
 
 	argc -= optind;
 	argv += optind;
-	if (!*argv)
+	if (*argv == NULL)
 		eerrorx("%s: you need to specify a service", applet);
-	if (!(service = rc_service_resolve(*argv)))
+	if ((service = rc_service_resolve(*argv)) == NULL) {
+		if (if_exists)
+			return 0;
 		eerrorx("%s: service `%s' does not exist", applet, *argv);
+	}
 	*argv = service;
 	execv(*argv, argv);
 	eerrorx("%s: %s", applet, strerror(errno));
